# Configuration exporters

```eval_rst
.. currentmodule:: baggianalysis.core

.. autosummary::
    :nosignatures:

    BaseExporter
    Cogli1Exporter
    GenericOxDNAExporter
    LAMMPSDataFileExporter
    
.. autoclass:: BaseExporter
    
.. autoclass:: Cogli1Exporter
    
.. autoclass:: Cogli1Particle

.. autoclass:: GenericOxDNAExporter 
    
.. autoclass:: LAMMPSDataFileExporter
```
